DROP TABLE IF EXISTS purchase_order_line_item CASCADE;
CREATE TABLE purchase_order_line_item (
    PURCHASE_ORDER_ID INT NOT NULL,
    LINE_ITEM_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS sale_order_line_item CASCADE;
CREATE TABLE sale_order_line_item (
    SALE_ORDER_ID INT NOT NULL,
    LINE_ITEM_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS purchase_order CASCADE;
CREATE TABLE purchase_order (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    ORDER_DATE DATE NOT NULL,
    USER_ID INT NOT NULL,
    STATUS_ID INT NOT NULL,
    VENDOR_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS sale_order CASCADE;
CREATE TABLE sale_order (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    ORDER_DATE DATE NOT NULL,
    USER_ID INT NOT NULL,
    CUSTOMER_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS order_status CASCADE;
CREATE TABLE order_status (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    STATUS VARCHAR(20) NOT NULL UNIQUE
) ENGINE = innodb;

DROP TABLE IF EXISTS line_item CASCADE;
CREATE TABLE line_item (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    MEDICINE_ID INT NOT NULL,
    UNIT_PRICE DOUBLE NOT NULL,
    UNITS INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS user CASCADE;
CREATE TABLE user (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    USERNAME VARCHAR(20) NOT NULL UNIQUE,
    PASSWORD VARCHAR(20) NOT NULL,
    FIRSTNAME VARCHAR(20) NOT NULL,
    LASTNAME VARCHAR(20) NOT NULL,
    EMAIL VARCHAR(20) NOT NULL UNIQUE,
    ADDRESS VARCHAR(50) NOT NULL,
    DESIGNATION VARCHAR(20) NOT NULL,
    QUALIFICATION VARCHAR(20) NOT NULL,
    EXPERIENCE VARCHAR(20) NOT NULL,
    JOINING_DATE DATE NOT NULL,
    SALARY DOUBLE NOT NULL,
    USERTYPEID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS usertype CASCADE;
CREATE TABLE usertype (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    USERTYPENAME VARCHAR(20) NOT NULL UNIQUE
) ENGINE = innodb;


ALTER TABLE user ADD CONSTRAINT user_usertype_fk FOREIGN KEY (USERTYPEID) REFERENCES usertype(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;

DROP TABLE IF EXISTS customer CASCADE;
CREATE TABLE customer (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    CUSTOMER_NAME VARCHAR(20) NOT NULL UNIQUE,
    PHONE VARCHAR(20) NOT NULL,
    GENDER VARCHAR(1) NOT NULL,
    ADDRESS VARCHAR(50) NOT NULL,
    AMOUNT_PAID DOUBLE,
    BALANCE DOUBLE
) ENGINE = innodb;

DROP TABLE IF EXISTS vendor CASCADE;
CREATE TABLE vendor (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    COMPANY_NAME VARCHAR(20) NOT NULL UNIQUE,
    PHONE VARCHAR(20) NOT NULL,    
    ADDRESS VARCHAR(50) NOT NULL,
    DEALER_NAME VARCHAR(50) NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS medicine CASCADE;
CREATE TABLE medicine (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    MEDICINE_NAME VARCHAR(20) NOT NULL UNIQUE,
    MANUFACTURER VARCHAR(20) NOT NULL,    
    UNIT_PRICE DOUBLE NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS transactiontype CASCADE;
CREATE TABLE transactiontype (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    TYPENAME VARCHAR(1) NOT NULL UNIQUE
) ENGINE = innodb;


DROP TABLE IF EXISTS receive_item CASCADE;
CREATE TABLE receive_item (
    PURCHASE_ORDER_ID INT NOT NULL,
    RECEIVED_DATE DATE NOT NULL,
    RECEIVED_BY INT NOT NULL,
    STORE_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS sell_item CASCADE;
CREATE TABLE sell_item (
    SALE_ORDER_ID INT NOT NULL,
    SALE_DATE DATE NOT NULL,
    SOLD_BY INT NOT NULL,
    STORE_ID INT NOT NULL
) ENGINE = innodb;

DROP TABLE IF EXISTS store CASCADE;
CREATE TABLE store (
    ID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
    MEDICINE_ID INT NOT NULL,
    UNIT_PRICE DOUBLE NOT NULL,
    UNITS INT NOT NULL,
    SOLD BIT NOT NULL DEFAULT 0
) ENGINE = innodb;


--Define FKs.
ALTER TABLE purchase_order_line_item ADD CONSTRAINT purchase_order_purchase_order_line_item_fk FOREIGN KEY (PURCHASE_ORDER_ID) REFERENCES purchase_order(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE purchase_order_line_item ADD CONSTRAINT line_item_purchase_order_line_item_fk FOREIGN KEY (LINE_ITEM_ID) REFERENCES line_item(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE sale_order_line_item ADD CONSTRAINT purchase_order_sale_order_line_item_fk FOREIGN KEY (SALE_ORDER_ID) REFERENCES sale_order(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE sale_order_line_item ADD CONSTRAINT line_item_sale_order_line_item_fk FOREIGN KEY (LINE_ITEM_ID) REFERENCES line_item(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE line_item ADD CONSTRAINT line_item_medicine_fk FOREIGN KEY (MEDICINE_ID) REFERENCES medicine(id) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE purchase_order ADD CONSTRAINT purchase_order_user_fk FOREIGN KEY (USER_ID) REFERENCES user(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE purchase_order ADD CONSTRAINT purchase_order_vendor_fk FOREIGN KEY (VENDOR_ID) REFERENCES vendor(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE purchase_order ADD CONSTRAINT purchase_order_order_status_fk FOREIGN KEY (STATUS_ID) REFERENCES order_status(id) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE sale_order ADD CONSTRAINT sale_order_user_fk FOREIGN KEY (USER_ID) REFERENCES user(id) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE sale_order ADD CONSTRAINT sale_order_customer_fk FOREIGN KEY (CUSTOMER_ID) REFERENCES customer(id) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE receive_item ADD CONSTRAINT receive_item_purchase_order_fk FOREIGN KEY (PURCHASE_ORDER_ID) REFERENCES purchase_order(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE receive_item ADD CONSTRAINT receive_item_user_fk FOREIGN KEY (RECEIVED_BY) REFERENCES user(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE receive_item ADD CONSTRAINT receive_item_store_fk FOREIGN KEY (STORE_ID) REFERENCES store(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE sell_item ADD CONSTRAINT sale_item_sale_order_fk FOREIGN KEY (sale_ORDER_ID) REFERENCES sale_order(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE sell_item ADD CONSTRAINT sale_item_user_fk FOREIGN KEY (SOLD_BY) REFERENCES user(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE sell_item ADD CONSTRAINT sale_item_store_fk FOREIGN KEY (STORE_ID) REFERENCES store(ID) ON DELETE NO ACTION ON UPDATE NO ACTION;

-- Test data.
INSERT INTO usertype (USERTYPENAME) VALUES('Administrator');
INSERT INTO usertype (USERTYPENAME) VALUES('Employee');

INSERT INTO user (USERNAME, PASSWORD, FIRSTNAME, LASTNAME, EMAIL, USERTYPEID, ADDRESS, DESIGNATION, QUALIFICATION, EXPERIENCE, JOINING_DATE, SALARY) 
    VALUES('admin', 'admin', 'test', 'test', 'admin@test.com', 1, 'Karachi', 'Administrator', 'Masters', '10 years', '2006-03-01', 100000);

INSERT INTO user (USERNAME, PASSWORD, FIRSTNAME, LASTNAME, EMAIL, USERTYPEID, ADDRESS, DESIGNATION, QUALIFICATION, EXPERIENCE, JOINING_DATE, SALARY) 
    VALUES('empl', 'empl', 'test', 'test', 'empl@test.com', 2, 'Karachi', 'Employee', 'Masters', '10 years', '2006-03-01', 100000);

INSERT INTO customer (CUSTOMER_NAME, PHONE, GENDER, ADDRESS, AMOUNT_PAID, BALANCE) 
    VALUES('customer1', '1231231', 'M', 'Karachi', 10000, 5000);
INSERT INTO customer (CUSTOMER_NAME, PHONE, GENDER, ADDRESS, AMOUNT_PAID, BALANCE) 
    VALUES('customer2', '1231231', 'M', 'Mumbai', 10000, 5000);
INSERT INTO customer (CUSTOMER_NAME, PHONE, GENDER, ADDRESS, AMOUNT_PAID, BALANCE) 
    VALUES('customer3', '1231231', 'F', 'Mumbai', 10000, 5000);

INSERT INTO vendor (COMPANY_NAME, PHONE, ADDRESS, DEALER_NAME) 
    VALUES('vendor1', '1231231', 'karachi, pakistan', 'test dealer1');
INSERT INTO vendor (COMPANY_NAME, PHONE, ADDRESS, DEALER_NAME) 
    VALUES('vendor2', '1231231', 'karachi, pakistan', 'test dealer2');
INSERT INTO vendor (COMPANY_NAME, PHONE, ADDRESS, DEALER_NAME) 
    VALUES('vendor3', '1231231', 'karachi, pakistan', 'test dealer2');

INSERT INTO medicine (MEDICINE_NAME,MANUFACTURER, UNIT_PRICE) 
    VALUES('medicine1', 'GB', 15);
INSERT INTO medicine (MEDICINE_NAME,MANUFACTURER, UNIT_PRICE) 
    VALUES('medicine2', 'GB', 15);

INSERT INTO transactiontype (TYPENAME) VALUES('B');
INSERT INTO transactiontype (TYPENAME) VALUES('S');

INSERT INTO order_status (STATUS) VALUES('PENDING');
INSERT INTO order_status (STATUS) VALUES('CANCELED');
INSERT INTO order_status (STATUS) VALUES('RECEIVED');
INSERT INTO order_status (STATUS) VALUES('RETURNED');

INSERT INTO purchase_order (ORDER_DATE, USER_ID, STATUS_ID, VENDOR_ID) VALUES ('2011-05-01', 1, 1, 1);
INSERT INTO purchase_order (ORDER_DATE, USER_ID, STATUS_ID, VENDOR_ID) VALUES ('2011-06-01', 2, 2, 2);

INSERT INTO line_item (MEDICINE_ID, UNIT_PRICE, UNITS) VALUES (1, 15, 10000);
INSERT INTO line_item (MEDICINE_ID, UNIT_PRICE, UNITS) VALUES (2, 15, 10000);
INSERT INTO line_item (MEDICINE_ID, UNIT_PRICE, UNITS) VALUES (2, 20, 10000);

INSERT INTO purchase_order_line_item(PURCHASE_ORDER_ID, LINE_ITEM_ID) VALUES (1, 1);
INSERT INTO purchase_order_line_item(PURCHASE_ORDER_ID, LINE_ITEM_ID) VALUES (1, 2);
INSERT INTO purchase_order_line_item(PURCHASE_ORDER_ID, LINE_ITEM_ID) VALUES (1, 3);



