/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.faziz.flexigrid.service;

import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.Root;
import org.faziz.flexigrid.service.dto.Page;

/**
 *
 * @author faisal
 */
public abstract class AbstractFacade<T> {

    private Class<T> entityClass;

    public AbstractFacade(Class<T> entityClass) {
        this.entityClass = entityClass;
    }

    protected abstract EntityManager getEntityManager();

    public void create(T entity) {
        getEntityManager().persist(entity);
    }

    public void edit(T entity) {
        getEntityManager().merge(entity);
    }

    public void remove(T entity) {
        getEntityManager().remove(getEntityManager().merge(entity));
    }

    public T find(Object id) {
        return getEntityManager().find(entityClass, id);
    }

    public Page<T> findAll() {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();
        cq.select(cq.from(entityClass));

        List<T> results = getEntityManager().createQuery(cq).getResultList();

        Page<T> page = new Page<T>();
        page.setRows(results);
        page.setTotal(results.size());
        page.setPage(1);

        return page;
    }

    public Page<T> getRequestedPage(Integer page, String qtype,
            String query, int rp, String sortname, String sortorder) {
        int count = findCount(
                page, qtype, query, rp, sortname, sortorder);
        
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().
                getCriteriaBuilder().createQuery();
        cq.select(cq.from(entityClass));

        List<T> results = getEntityManager().createQuery(cq).getResultList();

        
        Page<T> p = new Page<T>();
        p.setRows( results);
        p.setTotal( results.size());
        p.setPage(1);

        return p;
    }

    protected int findCount(Integer page, String qtype,
            String query, int rp, String sortname, String sortorder) {
        CriteriaBuilder cb = getEntityManager().
                getCriteriaBuilder();
        javax.persistence.criteria.CriteriaQuery cq = cb.createQuery();
        Root<T> c = cq.from(entityClass);
        cq.select(cb.count(c));
        return ((Number)getEntityManager().
            createQuery(cq).getSingleResult()).intValue();
    }

    public List<T> findRange(int[] range) {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();
        cq.select(cq.from(entityClass));
        javax.persistence.Query q = getEntityManager().createQuery(cq);
        q.setMaxResults(range[1] - range[0]);
        q.setFirstResult(range[0]);
        return q.getResultList();
    }

    public int count() {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();
        javax.persistence.criteria.Root<T> rt = cq.from(entityClass);
        cq.select(getEntityManager().getCriteriaBuilder().count(rt));
        javax.persistence.Query q = getEntityManager().createQuery(cq);
        return ((Long) q.getSingleResult()).intValue();
    }
}
